@@ -48,7 +48,7 @@ from ansiblelint.color import (
     render_yaml,
 )
 from ansiblelint.config import get_version_warning, options
-from ansiblelint.constants import EXIT_CONTROL_C_RC, LOCK_TIMEOUT_RC
+from ansiblelint.constants import EXIT_CONTROL_C_RC, GIT_CMD, LOCK_TIMEOUT_RC
 from ansiblelint.file_utils import abspath, cwd, normpath
 from ansiblelint.skip_utils import normalize_tag
 from ansiblelint.version import __version__
@@ -113,7 +113,7 @@ def initialize_options(arguments: list[str] | None = None) -> None:
     os.makedirs(options.cache_dir, exist_ok=True)
 
     options.cache_dir_lock = None
-    if not options.offline:
+    if not options.offline:  # pragma: no cover
         options.cache_dir_lock = FileLock(f"{options.cache_dir}/.lock")
         try:
             options.cache_dir_lock.acquire(timeout=180)
@@ -178,7 +178,7 @@ def _do_transform(result: LintResult, opts: Namespace) -> None:
 
 def support_banner() -> None:
     """Display support banner when running on unsupported platform."""
-    if sys.version_info < (3, 9, 0):
+    if sys.version_info < (3, 9, 0):  # pragma: no cover
         prefix = "::warning::" if "GITHUB_ACTION" in os.environ else "WARNING: "
         console_stderr.print(
             f"{prefix}ansible-lint is no longer tested under Python {sys.version_info.major}.{sys.version_info.minor} and will soon require 3.9. Do not report bugs for this version.",
@@ -192,7 +192,7 @@ def main(argv: list[str] | None = None) -> int:  # noqa: C901
     # alter PATH if needed (venv support)
     path_inject()
 
-    if argv is None:
+    if argv is None:  # pragma: no cover
         argv = sys.argv
     initialize_options(argv[1:])
 
@@ -238,7 +238,7 @@ def main(argv: list[str] | None = None) -> int:  # noqa: C901
 
     app = get_app()
     if isinstance(options.tags, str):
-        options.tags = options.tags.split(",")
+        options.tags = options.tags.split(",")  # pragma: no cover
     result = _get_matches(rules, options)
 
     if options.write_list:
@@ -304,7 +304,7 @@ def _previous_revision() -> Iterator[None]:
     rel_exclude_paths = [normpath(p) for p in options.exclude_paths]
     options.exclude_paths = [abspath(p, worktree_dir) for p in rel_exclude_paths]
     revision = subprocess.run(
-        ["git", "rev-parse", "HEAD^1"],
+        [*GIT_CMD, "rev-parse", "HEAD^1"],
         check=True,
         text=True,
         stdout=subprocess.PIPE,
@@ -318,14 +318,14 @@ def _previous_revision() -> Iterator[None]:
     # Run check will fail if worktree_dir already exists
     # pylint: disable=subprocess-run-check
     subprocess.run(
-        ["git", "worktree", "add", "-f", worktree_dir],
+        [*GIT_CMD, "worktree", "add", "-f", worktree_dir],
         stdout=subprocess.DEVNULL,
         stderr=subprocess.DEVNULL,
     )
     try:
         with cwd(worktree_dir):
             subprocess.run(
-                ["git", "checkout", revision],
+                [*GIT_CMD, "checkout", revision],
                 stdout=subprocess.DEVNULL,
                 stderr=subprocess.DEVNULL,
                 check=True,
@@ -365,10 +365,10 @@ def path_inject() -> None:
     # Expand ~ in PATH as it known to break many tools
     expanded = False
     for idx, path in enumerate(paths):
-        if "~" in path:
+        if "~" in path:  # pragma: no cover
             paths[idx] = os.path.expanduser(path)
             expanded = True
-    if expanded:
+    if expanded:  # pragma: no cover
         print(
             "WARNING: PATH altered to expand ~ in it. Read https://stackoverflow.com/a/44704799/99834 and correct your system configuration.",
             file=sys.stderr,
@@ -397,12 +397,13 @@ def path_inject() -> None:
     # We do know that finding ansible in PATH does not guarantee that it is
     # functioning or that is in fact the same version that was installed as
     # our dependency, but addressing this would be done by ansible-compat.
-    if not shutil.which("ansible"):
-        raise RuntimeError("Failed to find ansible executable in PATH")
+    for cmd in ("ansible", "git"):
+        if not shutil.which(cmd):
+            raise RuntimeError(f"Failed to find runtime dependency '{cmd}' in PATH")
 
 
 # Based on Ansible implementation
-def to_bool(value: Any) -> bool:
+def to_bool(value: Any) -> bool:  # pragma: no cover
     """Return a bool for the arg."""
     if value is None or isinstance(value, bool):
         return bool(value)
