@@ -16,12 +16,14 @@ from ansiblelint.constants import (
     INVALID_CONFIG_RC,
 )
 from ansiblelint.file_utils import (
+    Lintable,
     abspath,
     expand_path_vars,
     guess_project_dir,
     normpath,
 )
-from ansiblelint.loaders import YAMLError, yaml_load_safe
+from ansiblelint.schemas.main import validate_file_schema
+from ansiblelint.yaml_utils import clean_json
 
 _logger = logging.getLogger(__name__)
 _PATH_VARS = [
@@ -64,28 +66,18 @@ def load_config(config_file: str) -> dict[Any, Any]:
         # a missing default config file should not trigger an error
         return {}
 
-    try:
-        with open(config_path, encoding="utf-8") as stream:
-            config = yaml_load_safe(stream)
-            # We want to allow passing /dev/null to disable config use
-            if config is None:
-                return {}
-            if not isinstance(config, dict):
-                _logger.error("Invalid configuration file %s", config_path)
-                sys.exit(INVALID_CONFIG_RC)
-    except YAMLError as exc:
-        _logger.error(exc)
+    config_lintable = Lintable(
+        config_path, kind="ansible-lint-config", base_kind="text/yaml"
+    )
+
+    for error in validate_file_schema(config_lintable):
+        _logger.error("Invalid configuration file %s. %s", config_path, error)
         sys.exit(INVALID_CONFIG_RC)
 
+    config = clean_json(config_lintable.data)
+    if not isinstance(config, dict):
+        raise RuntimeError("Schema failed to properly validate the config file.")
     config["config_file"] = config_path
-    # See https://github.com/ansible-community/ansible-lint/issues/1803
-    if isinstance(config, list):
-        _logger.error(
-            "Invalid configuration '%s', expected YAML mapping in the config file.",
-            config_path,
-        )
-        sys.exit(INVALID_CONFIG_RC)
-
     config_dir = os.path.dirname(config_path)
     expand_to_normalized_paths(config, config_dir)
 
@@ -217,10 +209,18 @@ def get_cli_parser() -> argparse.ArgumentParser:
     parser = argparse.ArgumentParser()
 
     listing_group = parser.add_mutually_exclusive_group()
+    listing_group.add_argument(
+        "-P",
+        "--list-profiles",
+        dest="list_profiles",
+        default=False,
+        action="store_true",
+        help="List all profiles, no formatting options available.",
+    )
     listing_group.add_argument(
         "-L",
         "--list-rules",
-        dest="listrules",
+        dest="list_rules",
         default=False,
         action="store_true",
         help="List all the rules. For listing rules only the following formats "
@@ -229,7 +229,7 @@ def get_cli_parser() -> argparse.ArgumentParser:
     listing_group.add_argument(
         "-T",
         "--list-tags",
-        dest="listtags",
+        dest="list_tags",
         action="store_true",
         help="List all the tags and the rules they cover. Increase the verbosity level "
         "with `-v` to include 'opt-in' tag and its rules.",
@@ -260,16 +260,12 @@ def get_cli_parser() -> argparse.ArgumentParser:
         help="quieter, reduce verbosity, can be specified twice.",
     )
     parser.add_argument(
-        "-P",
         "--profile",
-        # * allow to distinguish between calling without -P, with -P and
-        # with -P=foo, while '?' does not. We do not support a real list.
-        nargs="*",
         dest="profile",
-        default=None,  # when called with -P but no arg will load as empty list []
+        default=None,
         action="store",
         choices=PROFILES.keys(),
-        help="Specify which rules profile to be used, or displays available profiles when no argument is given.",
+        help="Specify which rules profile to be used.",
     )
     parser.add_argument(
         "-p",
@@ -284,9 +280,9 @@ def get_cli_parser() -> argparse.ArgumentParser:
         dest="progressive",
         default=False,
         action="store_true",
-        help="Return success if it detects a reduction in number"
-        " of violations compared with previous git commit. This "
-        "feature works only in git repositories.",
+        help="Return success if number of violations compared with"
+        "previous git commit has not increased. This feature works"
+        "only in git repositories.",
     )
     parser.add_argument(
         "--project-dir",
@@ -419,7 +415,7 @@ def get_cli_parser() -> argparse.ArgumentParser:
         dest="offline",
         action="store_const",
         const=True,
-        help="Disable installation of requirements.yml",
+        help="Disable installation of requirements.yml and schema refreshing",
     )
     parser.add_argument(
         "--version",
@@ -442,6 +438,7 @@ def merge_config(file_config: dict[Any, Any], cli_config: Namespace) -> Namespac
         "display_relative_path",
         "parseable",
         "quiet",
+        "strict",
         "use_default_rules",
         "progressive",
         "offline",
@@ -456,12 +453,15 @@ def merge_config(file_config: dict[Any, Any], cli_config: Namespace) -> Namespac
         "mock_modules": [],
         "mock_roles": [],
         "enable_list": [],
+        "only_builtins_allow_collections": [],
+        "only_builtins_allow_modules": [],
         # do not include "write_list" here. See special logic below.
     }
 
     scalar_map = {
         "loop_var_prefix": None,
         "project_dir": ".",
+        "profile": None,
     }
 
     if not file_config:
@@ -473,11 +473,13 @@ def merge_config(file_config: dict[Any, Any], cli_config: Namespace) -> Namespac
         return cli_config
 
     for entry in bools:
-        v = getattr(cli_config, entry) or file_config.pop(entry, False)
+        file_value = file_config.pop(entry, False)
+        v = getattr(cli_config, entry) or file_value
         setattr(cli_config, entry, v)
 
     for entry, default in scalar_map.items():
-        v = getattr(cli_config, entry, None) or file_config.pop(entry, default)
+        file_value = file_config.pop(entry, default)
+        v = getattr(cli_config, entry, None) or file_value
         setattr(cli_config, entry, v)
 
     # if either commandline parameter or config file option is set merge
@@ -522,7 +524,7 @@ def get_config(arguments: list[str]) -> Namespace:
     options = parser.parse_args(arguments)
 
     # docs is not document, being used for internal documentation building
-    if options.listrules and options.format not in ["plain", "rich", "md", "docs"]:
+    if options.list_rules and options.format not in ["plain", "rich", "md", "docs"]:
         parser.error(
             f"argument -f: invalid choice: '{options.format}'. "
             f"In combination with argument -L only 'plain', "
