@@ -19,7 +19,7 @@ import wcmatch.pathlib
 from wcmatch.wcmatch import RECURSIVE, WcMatch
 
 from ansiblelint.config import BASE_KINDS, options
-from ansiblelint.constants import FileType
+from ansiblelint.constants import GIT_CMD, FileType
 
 if TYPE_CHECKING:
     # https://github.com/PyCQA/pylint/issues/3979
@@ -183,6 +183,7 @@ class Lintable:
         name: str | Path,
         content: str | None = None,
         kind: FileType | None = None,
+        base_kind: str = "",
     ):
         """Create a Lintable instance."""
         self.dir: str = ""
@@ -212,7 +213,7 @@ class Lintable:
             role = self.path
             while role.parent.name != "roles" and role.name:
                 role = role.parent
-            if role.exists:
+            if role.exists():
                 self.role = role.name
 
         if str(self.path) in ["/dev/stdin", "-"]:
@@ -236,7 +237,7 @@ class Lintable:
                 self.dir = str(self.path.parent.resolve())
 
         # determine base file kind (yaml, xml, ini, ...)
-        self.base_kind = kind_from_path(self.path, base=True)
+        self.base_kind = base_kind or kind_from_path(self.path, base=True)
         self.abspath = self.path.expanduser().absolute()
 
     def __getitem__(self, key: Any) -> Any:
@@ -367,14 +368,14 @@ def discover_lintables(options: Namespace) -> dict[str, Any]:
     """
     # git is preferred as it also considers .gitignore
     git_command_present = [
-        "git",
+        *GIT_CMD,
         "ls-files",
         "--cached",
         "--others",
         "--exclude-standard",
         "-z",
     ]
-    git_command_absent = ["git", "ls-files", "--deleted", "-z"]
+    git_command_absent = [*GIT_CMD, "ls-files", "--deleted", "-z"]
     out = None
 
     try:
@@ -436,7 +437,7 @@ def guess_project_dir(config_file: str | None) -> str:
     if path is None:
         try:
             result = subprocess.run(
-                ["git", "rev-parse", "--show-toplevel"],
+                [*GIT_CMD, "rev-parse", "--show-toplevel"],
                 capture_output=True,
                 text=True,
                 check=True,
