@@ -19,10 +19,6 @@ if TYPE_CHECKING:
 else:
     CompletedProcess = subprocess.CompletedProcess
 
-# Emulate command line execution initialization as without it Ansible module
-# would be loaded with incomplete module/role/collection list.
-app = get_app(offline=True)
-
 # pylint: disable=wrong-import-position
 from ansiblelint.runner import Runner  # noqa: E402
 
@@ -30,8 +26,15 @@ from ansiblelint.runner import Runner  # noqa: E402
 class RunFromText:
     """Use Runner on temp files created from testing text snippets."""
 
+    app = None
+
     def __init__(self, collection: RulesCollection) -> None:
         """Initialize a RunFromText instance with rules collection."""
+        # Emulate command line execution initialization as without it Ansible module
+        # would be loaded with incomplete module/role/collection list.
+        if not self.app:  # pragma: no cover
+            self.app = get_app()
+
         self.collection = collection
 
     def _call_runner(self, path: str) -> list[MatchError]:
@@ -59,6 +62,7 @@ class RunFromText:
         os.makedirs(tasks_path)
         with open(os.path.join(tasks_path, "main.yml"), "w", encoding="utf-8") as fh:
             fh.write(tasks_main_text)
+            fh.flush()
         results = self._call_runner(role_path)
         shutil.rmtree(role_path)
         return results
@@ -70,6 +74,7 @@ class RunFromText:
         os.makedirs(meta_path)
         with open(os.path.join(meta_path, "main.yml"), "w", encoding="utf-8") as fh:
             fh.write(meta_main_text)
+            fh.flush()
         results = self._call_runner(role_path)
         shutil.rmtree(role_path)
         return results
@@ -81,6 +86,7 @@ class RunFromText:
         os.makedirs(defaults_path)
         with open(os.path.join(defaults_path, "main.yml"), "w", encoding="utf-8") as fh:
             fh.write(defaults_main_text)
+            fh.flush()
         results = self._call_runner(role_path)
         shutil.rmtree(role_path)
         return results
@@ -95,7 +101,7 @@ def run_ansible_lint(
 ) -> CompletedProcess:
     """Run ansible-lint on a given path and returns its output."""
     args = [*argv]
-    if offline:
+    if offline:  # pragma: no cover
         args.insert(0, "--offline")
 
     if not executable:
